Learn R Programming

movementsync (version 0.1.5)

ave_cross_power_spliceview: Get the average cross power on each segment in a SplicedView

Description

Get the average cross power on each segment in a SplicedView

Usage

ave_cross_power_spliceview(
  sv,
  columns,
  colour = "blue",
  segments = NULL,
  show_plot = FALSE,
  ...
)

Value

data.frame with columns containing Average Cross Power for each segment.

Arguments

sv

SplicedView object

columns

column names in the data of each SplicedView object.

colour

name of colour on plots (default is 'blue').

segments

indices of segments to plot e.g. 1:10 (default plots up to first 10).

show_plot

show a plot (default is FALSE).

...

passed to analyze_coherency().

See Also

Other statistical and analysis functions: apply_column_spliceview(), apply_segment_spliceview(), ave_cross_power_over_splices(), ave_power_over_splices(), ave_power_spliceview(), calculate_ave_cross_power1(), calculate_ave_power1(), compare_ave_cross_power1(), compare_ave_power1(), compare_avg_cross_power2(), compare_avg_power2(), difference_onsets(), pull_segment_spliceview(), sample_gap_splice(), sample_offset_splice(), summary_onsets(), visualise_sample_splices()

Examples

Run this code
r <- get_sample_recording()
d1 <- get_duration_annotation_data(r)
# only one relevant section for sample data
splicing_smile_df <- splice_time(d1, tier ='INTERACTION',
  comments = 'Mutual look and smile')

fv_list <- get_filtered_views(r, data_points = "Nose", n = 41, p = 3)
jv <- get_joined_view(fv_list)
sv_duration_smile <- get_spliced_view(jv, splicing_df = splicing_smile_df)
ave_cross_power_smile <- ave_cross_power_spliceview(
  sv_duration_smile, columns = c("Nose_x_Central_Sitar", "Nose_y_Central_Sitar"), show_plot = TRUE)
head(ave_cross_power_smile)

Run the code above in your browser using DataLab